Learn R Programming

gstsm (version 1.0.0)

generate_candidates.gstsm: Generate Candidates - GSTSM implementation

Description

The algorithm combines SRGs that have sequences of size k, received as input, to generate candidates with sequences of size k + 1. Let x and y be SRGs, the conditions for this to occur are: that we have an intersection of candidates over the time range, intersection over the set of spatial positions (x.g n y.g), and a common subsequence: <x.s2, . . . , x.sk>=<y.s1, . . . , y.sk-1>.

Usage

# S3 method for gstsm
generate_candidates(object, srg)

Value

candidate sequences of size k + 1

Arguments

object

a GSTSM object

srg

set of Solid Ranged Groups