validate_and_close: Validate and Close
Description
The function receives as input the set of RGs (RG) from a candidate and the
minimum size of a group (beta).
It starts defining a set of elements that will be removed from the
set of RGs, if it does not have the minimum group size.
Usage
validate_and_close(c, gamma, beta)
Value
validated Greedy-Ranged-Groups.
Arguments
- c
candidate
- gamma
minimum temporal frequency
- beta
minimum group size